@@ -1,7 +1,7 @@
 /*
 MIT License
 
-Copyright (c) 2023 Advanced Micro Devices, Inc. All rights reserved.
+Copyright (c) 2024 - 2025 Advanced Micro Devices, Inc. All rights reserved.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -68,8 +68,8 @@ int main(int argc, const char **argv) {
             "gray_scale/rgb/rgbplanar display_on_off external_source_mode<external_file_mode=0/raw_compressed_mode=1/raw_uncompresses_mode=2>\n");
         return -1;
     }
-    int argIdx = 0;
-    const char *folder_path = argv[++argIdx];
+    int argIdx = 1;
+    const char *folder_path = argv[argIdx++];
     bool display = 1;            // Display the images
     int rgb = 1;                 // process color images
     int decode_width = 224;      // Decoding width
@@ -78,19 +78,19 @@ int main(int argc, const char **argv) {
     bool processing_device = 0;  // CPU Processing
     int mode = 0;                // File mode
 
-    if (argc >= argIdx + MIN_ARG_COUNT) processing_device = atoi(argv[++argIdx]);
+    if (argc > argIdx) processing_device = atoi(argv[argIdx++]);
 
-    if (argc >= argIdx + MIN_ARG_COUNT) decode_width = atoi(argv[++argIdx]);
+    if (argc > argIdx) decode_width = atoi(argv[argIdx++]);
 
-    if (argc >= argIdx + MIN_ARG_COUNT) decode_height = atoi(argv[++argIdx]);
+    if (argc > argIdx) decode_height = atoi(argv[argIdx++]);
 
-    if (argc >= argIdx + MIN_ARG_COUNT) input_batch_size = atoi(argv[++argIdx]);
+    if (argc > argIdx) input_batch_size = atoi(argv[argIdx++]);
 
-    if (argc >= argIdx + MIN_ARG_COUNT) rgb = atoi(argv[++argIdx]);
+    if (argc > argIdx) rgb = atoi(argv[argIdx++]);
 
-    if (argc >= argIdx + MIN_ARG_COUNT) display = atoi(argv[++argIdx]);
+    if (argc > argIdx) display = atoi(argv[argIdx++]);
 
-    if (argc >= argIdx + MIN_ARG_COUNT) mode = atoi(argv[++argIdx]);
+    if (argc > argIdx) mode = atoi(argv[argIdx++]);
 
     std::cerr << "\n Mode:: " << mode << std::endl;
     std::cerr << ">>> Running on " << (processing_device ? "GPU" : "CPU") << std::endl;
@@ -130,6 +130,12 @@ int main(int argc, const char **argv) {
         file_path.append(_entity->d_name);
         file_names.push_back(file_path);
     }
+
+    if (file_names.empty()) {
+        std::cerr << "[ERR] No files detected in the given path, Pass a folder with images\n";
+        return -1;
+    }
+
     if (mode != 0) {
         if (mode == 1) {
             // Mode 1 is Raw compressed
@@ -258,11 +264,11 @@ int main(int argc, const char **argv) {
             if (mode == 0) {
                 input_images.push_back(file_names.back());
                 file_names.pop_back();
-                if ((file_names.size()) == 0) {
-                    eos = true;
-                }
                 label_buffer.push_back(labels.back());
                 labels.pop_back();
+                if ((file_names.size()) < input_batch_size) {
+                    eos = true;
+                }
             } else {
                 if (mode == 1) {
                     input_batch_buffer.push_back(input_buffer.back());
@@ -281,12 +287,12 @@ int main(int argc, const char **argv) {
                     label_buffer.push_back(labels.back());
                     labels.pop_back();
                 }
-                if ((file_names.size()) == 0 || input_buffer.size() == 0) {
+                if ((file_names.size()) < input_batch_size || input_buffer.size() < input_batch_size) {
                     eos = true;
                 }
             }
         }
-        if (index + 1 <= (total_images / input_batch_size)) {
+        if (index + 1 <= total_images / input_batch_size) {
             std::cerr << "\n Processing Batch: " << index << "\n Mode: " << mode;
             if (mode == 0) {
                 rocalExternalSourceFeedInput(handle, input_images, set_labels, {}, ROI_xywh,
@@ -306,13 +312,15 @@ int main(int argc, const char **argv) {
             }
         }
         if (rocalRun(handle) != 0) {
-            std::cerr << "rocalRun Failed!";
-            break;
+            std::cerr << "rocalRun Failed with runtime error!";
+            rocalRelease(handle);
+            return -1;
         }
 
+        output_tensor_list = rocalGetOutputTensors(handle);
+
         if (!display) continue;
         // Dump the output image
-        output_tensor_list = rocalGetOutputTensors(handle);
         std::vector<int> compression_params;
         compression_params.push_back(IMWRITE_PNG_COMPRESSION);
         compression_params.push_back(9);
@@ -391,7 +399,7 @@ int main(int argc, const char **argv) {
                     int *labels_ptr = static_cast<int *>(label_buffer.data());
                     for (size_t i = 0; i < label_buffer.size(); i++) {
                         labels_tensor_list->at(i)->set_mem_handle(labels_ptr);
-                        std::cerr << "\nLabels[" << i << "]: " << labels_ptr[i] << "\t";
+                        std::cerr << "\nLabels[" << i << "]: " << *labels_ptr << "\t";
                         labels_ptr++;
                     }
                 }
